##  Finishing a Survey
It is recommended to finish a survey once all recipients have completed it or after it has served its purpose. Keeping a survey with a dynamic scope unnecessarily running can lead to unintended notifications and unwanted responses from the recipients.
To manually finish a survey run, follow these steps:
  1. From the Manage Surveys section of the Collaboration tab, select the survey that needs to be finished.
  2. Click Finish Survey at the top right.
